[![PyPi Version](https://img.shields.io/pypi/v/tesla-ce.svg)](https://pypi.python.org/pypi/tesla-ce/)
[![codecov](https://codecov.io/gh/tesla-ce/core/branch/main/graph/badge.svg?token=PJJQMW981P)](https://codecov.io/gh/tesla-ce/core)
[![Vulnerability scan](https://github.com/tesla-ce/core/actions/workflows/debricked.yml/badge.svg)](https://github.com/tesla-ce/core/actions/workflows/debricked.yml)
[![CodeQL](https://github.com/tesla-ce/core/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/tesla-ce/core/actions/workflows/codeql-analysis.yml)
[![AGPL License](https://img.shields.io/badge/license-AGPL-blue.svg)](http://www.gnu.org/licenses/agpl-3.0)
[![FOSSA Status](https://app.fossa.com/api/projects/custom%2B26246%2Fgithub.com%2Ftesla-ce%2Fcore.svg?type=shield)](https://app.fossa.com/projects/custom%2B26246%2Fgithub.com%2Ftesla-ce%2Fcore?ref=badge_shield)
[![Quality gate](https://sonar.sunai.uoc.edu/api/project_badges/quality_gate?project=tesla-ce_core)](https://sonar.sunai.uoc.edu/dashboard?id=tesla-ce_core)

# TeSLA CE Core System

| :warning: This repository is **under construction**. Final release of TeSLA Community Edition source code is expected by the **end of 2021** |
| --- |

## Description
Description: A description of your project follows. A good description is clear, short, and to the point. Describe the importance of your project, and what it does.

## Installation
Installation: Installation is the next section in an effective README. Tell other users how to install your project locally. Optionally, include a gif to make the process even more clear for other people.

## Usage
Usage: The next section is usage, in which you instruct other people on how to use your project after they’ve installed it. This would also be a good place to include screenshots of your project in action.

## Contributing
Contributing: Larger projects often have sections on contributing to their project, in which contribution instructions are outlined. Sometimes, this is a separate file. If you have specific contribution preferences, explain them so that other developers know how to best contribute to your work. To learn more about how to help others contribute, check out the guide for setting guidelines for repository contributors.

## Credits
Credits: Include a section for credits in order to highlight and link to the authors of your project.

## License
This project is licensed under [AGPL v3 licence](http://www.gnu.org/licenses/agpl-3.0).

[![FOSSA Status](https://app.fossa.com/api/projects/custom%2B26246%2Fgithub.com%2Ftesla-ce%2Fcore.svg?type=large)](https://app.fossa.com/projects/custom%2B26246%2Fgithub.com%2Ftesla-ce%2Fcore?ref=badge_large)
